@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3491 2010-08-17 06:18:11Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3651 2010-09-29 10:51:05Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -43,9 +43,12 @@ class ScriptLibInfo
 	const LIB_JQUERY_CURVYCORNERS	= 'jquery.curvycorners';
 	const LIB_JQUERY_PRETTYPHOTO	= 'jquery.prettyphoto';
 	const LIB_JQUERY_QTIP			= 'jquery.qtip';
+	const LIB_JQUERY_CALCULATION	= 'jquery.calculation';
+	
 	// jQueryプラグインバージョン
 	const JQUERY_PRETTYPHOTO_VER	= '2.5.6';
 	const JQUERY_QTIP_VER			= '1.0';
+	const JQUERY_CALCULATION_VER	= '0.4.07';
 	
 	// jQuery UI
 	const LIB_JQUERY_UI_WIDGETS_ACCORDION		= 'jquery-ui.accordion';		// Widgets Accordion
@@ -85,6 +88,7 @@ class ScriptLibInfo
 	const JQUERY_PRETTYPHOTO_FILENAME	= 'jquery/jquery.prettyPhoto.js';
 	const JQUERY_PRETTYPHOTO_CSS		= 'jquery/prettyPhoto/css/prettyPhoto.css';
 	const JQUERY_QTIP_FILENAME			= 'jquery/jquery.qtip-1.0.min.js';
+	const JQUERY_CALCULATION_FILENAME	= 'jquery/jquery.calculation.js';
 	
 	// ライブラリの公式サイトのURL
 	const JQUERY_CLUETIP_URL			= 'http://plugins.learningjquery.com/cluetip/';
@@ -92,6 +96,7 @@ class ScriptLibInfo
 	const JQUERY_CURVYCORNERS_URL		= 'http://code.google.com/p/jquerycurvycorners/';
 	const JQUERY_PRETTYPHOTO_URL		= 'http://www.no-margin-for-errors.com/projects/prettyphoto-jquery-lightbox-clone/';
 	const JQUERY_QTIP_URL				= 'http://craigsworks.com/projects/qtip/';
+	const JQUERY_CALCULATION_URL		= 'http://www.pengoworks.com/workshop/jquery/calculation/calculation.plugin.htm';
 	
 	// ディレクトリ名
 	const FCKEDITOR_DIRNAME				= 'fckeditor2.6.6';				// FCKEditor
@@ -213,7 +218,10 @@ class ScriptLibInfo
 																'version'	=>	self::JQUERY_PRETTYPHOTO_VER),
 					self::LIB_JQUERY_QTIP			=>	array(	'script' 	=> array(self::JQUERY_QTIP_FILENAME),	// jquery.qtip用のファイル
 																'url'		=>	self::JQUERY_QTIP_URL,
-																'version'	=>	self::JQUERY_QTIP_VER)
+																'version'	=>	self::JQUERY_QTIP_VER),
+					self::LIB_JQUERY_CALCULATION	=>	array(	'script' 	=> array(self::JQUERY_CALCULATION_FILENAME),	// jquery.calculation用のファイル
+																'url'		=>	self::JQUERY_CALCULATION_URL,
+																'version'	=>	self::JQUERY_CALCULATION_VER)
 																);
 					
 		// 使用するjQueryバージョンに合わせてファイルを追加
