@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 3390 2010-07-17 05:00:10Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 3639 2010-09-27 09:54:19Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -22,7 +22,7 @@
 INSERT INTO _system_config 
 (sc_id,                          sc_value,                  sc_name) VALUES
 ('system_name',                 'Magic3',                   'システム名称'),
-('db_version',                  '2010070901',               'DBバージョン'),
+('db_version',                  '2010091801',               'DBバージョン'),
 ('server_id',                   '',                         'サーバ識別用ID'),
 ('server_url',                  '',                         'サーバURL'),
 ('default_lang',                'ja',                       'デフォルト言語'),
@@ -55,6 +55,7 @@ INSERT INTO _system_config
 ('smartphone_default_template', 's/default',                'スマートフォン画面用デフォルトテンプレート'),
 ('msg_template',                '_admin',                   'メッセージ表示用テンプレート'),
 ('use_template_id_in_session',  '1',                        'セッションにテンプレートIDを保存'),
+('admin_default_theme',         'start',                    '管理画面用jQueryUIテーマ'),
 ('head_title_format',           '$1;$1 - $2;$1 - $2 - $3;', 'HTMLヘッダタイトルフォーマット'),
 ('mobile_auto_redirect',        '0',                        '携帯アクセスの自動遷移'),
 ('mobile_use_session',           '1',                       '携帯セッション管理'),
@@ -81,6 +82,11 @@ INSERT INTO _login_user
 (lu_id, lu_account, lu_password,  lu_name,  lu_user_type, lu_assign, lu_create_dt) VALUES
 (1,     'admin',    md5('admin'), '管理者', 100,          'sy,',     now());
 
+-- 追加クラスマスター
+INSERT INTO _addons
+(ao_id,     ao_class_name, ao_name,            ao_description) VALUES
+('bloglib', 'blogLib',     'ブログライブラリ', '');
+
 -- 管理画面メニューデータ
 INSERT INTO _nav_item
 (ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,        ni_view_control, ni_param, ni_name,                ni_help_title,          ni_help_body) VALUES
@@ -107,13 +113,6 @@ INSERT INTO _nav_item
 (1100,  0,            11,       'admin_menu', '_others',         0,               '',       'その他',               '',                     ''),
 (1101,  1100,         0,        'admin_menu', 'logout',          0,               '',       'ログアウト',           'ログアウト',           '管理機能からログアウトします。');
 
--- ウィジェット情報マスター
-INSERT INTO _widgets
-(wd_id,         wd_name, wd_type, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
-('admin_menu',  '管理用メニュー',  'ADMN',  '',     'Naoki Hirata', 'Magic3.org', 'GPL', 10,      '', true,            true,        false,        false,       false,        false,          false, true, 100, now(),now()),
-('admin_menu2', '管理用メニュー2', 'ADM2',  '',     'Naoki Hirata', 'Magic3.org', 'GPL', 10,    '', true,            true,        false,        false,       false,        false,          false, true, 100, now(),now()),
-('admin_main',  '管理用画面',      'ADBD',  '',     'Naoki Hirata', 'Magic3.org', 'GPL', 10,     'pagedef=jquery-ui-plus;pagedef_mobile=jquery-ui-plus;pagedef_smartphone=jquery-ui-plus;menudef=jquery.simpletree;', true, true,        false,        false,       false,        true,          false, true, 0,   now(),now());
-
 -- ページIDマスター
 INSERT INTO _page_id 
 (pg_id,          pg_type, pg_default_sub_id, pg_path,       pg_name,                            pg_description,                       pg_priority, pg_device_type, pg_active, pg_mobile, pg_editable) VALUES
