@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 3554 2010-08-31 04:58:34Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 3597 2010-09-17 01:41:17Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -654,9 +654,10 @@ class admin_mainDb extends BaseDb
 	 * @param string $template		テンプレートID
 	 * @param int $authType			アクセス制御タイプ(0=管理者のみ、1=制限なし、2=ログインユーザ)
 	 * @param bool $ssl				SSLを使用するかどうか
+	 * @param bool $userLimited		ユーザ制限するかどうか
 	 * @return					true = 正常、false=異常
 	 */
-	function updatePageInfo($pageId, $pageSubId, $contentType='', $template='', $authType=0, $ssl=false)
+	function updatePageInfo($pageId, $pageSubId, $contentType='', $template='', $authType=0, $ssl = false, $userLimited = false)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$user = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -724,11 +725,12 @@ class admin_mainDb extends BaseDb
 		$queryStr .=  'pn_content_type, ';
 		$queryStr .=  'pn_auth_type, ';
 		$queryStr .=  'pn_use_ssl, ';
+		$queryStr .=  'pn_user_limited, ';
 		$queryStr .=  'pn_create_user_id, ';
 		$queryStr .=  'pn_create_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$ret =$this->execStatement($queryStr, array($pageId, $pageSubId, ''/*言語なし*/, $historyIndex, $template, $metaTitle, $metaDesc, $metaKeyword, $contentType, $authType, intval($ssl), $user, $now));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$ret =$this->execStatement($queryStr, array($pageId, $pageSubId, ''/*言語なし*/, $historyIndex, $template, $metaTitle, $metaDesc, $metaKeyword, $contentType, $authType, intval($ssl), intval($userLimited), $user, $now));
 			
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -753,6 +755,7 @@ class admin_mainDb extends BaseDb
 		$contentType = '';
 		$authType = 0;
 		$ssl = false;
+		$userLimited = false;
 		
 		// トランザクション開始
 		$this->startTransaction();
@@ -771,7 +774,8 @@ class admin_mainDb extends BaseDb
 			$contentType = $row['pn_content_type'];
 			$authType = $row['pn_auth_type'];
 			$ssl = $row['pn_use_ssl'];
-		
+			$userLimited = $row['pn_user_limited'];
+			
 			// レコードが削除されていない場合は削除
 			if (!$row['pn_deleted']){
 				// 古いレコードを削除
@@ -802,11 +806,12 @@ class admin_mainDb extends BaseDb
 		$queryStr .=  'pn_content_type, ';
 		$queryStr .=  'pn_auth_type, ';
 		$queryStr .=  'pn_use_ssl, ';
+		$queryStr .=  'pn_user_limited, ';
 		$queryStr .=  'pn_create_user_id, ';
 		$queryStr .=  'pn_create_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$ret =$this->execStatement($queryStr, array($pageId, $pageSubId, $langId, $historyIndex, $template, $metaTitle, $metaDesc, $metaKeyword, $contentType, $authType, intval($ssl), $user, $now));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$ret =$this->execStatement($queryStr, array($pageId, $pageSubId, $langId, $historyIndex, $template, $metaTitle, $metaDesc, $metaKeyword, $contentType, $authType, intval($ssl), intval($userLimited), $user, $now));
 			
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -1209,7 +1214,7 @@ class admin_mainDb extends BaseDb
 		
 		$queryStr = 'SELECT * FROM _login_user ';
 		$queryStr .=  'WHERE lu_deleted = false ';// 削除されていない
-		$queryStr .=  'ORDER BY lu_account limit ' . $limit . ' offset ' . $offset;
+		$queryStr .=  'ORDER BY lu_user_type, lu_account limit ' . $limit . ' offset ' . $offset;
 		$this->selectLoop($queryStr, array(), $callback);
 	}
 	/**
