@@ -8,15 +8,27 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainBaseWidgetContainer.php 2456 2009-10-24 03:43:03Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainBaseWidgetContainer.php 3614 2010-09-22 05:09:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() . '/blog_mainDb.php');
 
 class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 {
+	protected $_db;			// DB接続オブジェクト
+	protected $_configArray;		// BBS定義値
+	const CF_RECEIVE_COMMENT		= 'receive_comment';		// コメントを受け付けるかどうか
+	const CF_RECEIVE_TRACKBACK		= 'receive_trackback';		// トラックバックを受け付けるかどうか
+	const CF_ENTRY_VIEW_COUNT		= 'entry_view_count';			// 記事表示数
+	const CF_ENTRY_VIEW_ORDER		= 'entry_view_order';			// 記事表示方向
+	const CF_USE_MULTI_BLOG		= 'use_multi_blog';		// マルチブログ機能を使用するかどうか
+	const CF_MULTI_BLOG_TOP_CONTENT	= 'multi_blog_top_content';		// マルチブログ時のトップコンテンツ
+	const CF_CATEGORY_COUNT			= 'category_count';		// カテゴリ数
+	const DEFAULT_CATEGORY_COUNT	= 2;				// デフォルトのカテゴリ数
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -24,6 +36,15 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
+		
+		// サブウィジェット起動のときだけ初期処理実行
+		if ($this->gEnv->getIsSubWidget()){
+			// DBオブジェクト作成
+			$this->_db = new blog_mainDb();
+		
+			// BBS定義を読み込む
+			$this->_loadConfig();
+		}
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -63,7 +84,11 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 				break;
 			case 'category':		// カテゴリ設定
 			case 'category_detail':		// カテゴリ設定
-				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; カテゴリ設定';// パンくずリスト
+				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; カテゴリ';// パンくずリスト
+				break;
+			case 'blogid':		// マルチブログ設定
+			case 'blogid_detail':		// マルチブログ設定
+				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; マルチブログ';// パンくずリスト
 				break;
 		}
 
@@ -90,6 +115,8 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 		$link = $baseUrl . '&task=category';
 		if ($task == 'category' ||		// カテゴリ設定
 			$task == 'category_detail' ||		// カテゴリ設定
+			$task == 'blogid' ||		// マルチブログ
+			$task == 'blogid_detail' ||		// マルチブログ詳細
 			$task == 'config'){		// ブログ設定
 			$current = 'id="current"';
 		}
@@ -121,13 +148,21 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 			$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>コメント一覧</span></a></li>' . M3_NL;
 		} else if ($task == 'category' ||		// カテゴリ設定
 			$task == 'category_detail' ||		// カテゴリ設定
+			$task == 'blogid' ||		// マルチブログ
+			$task == 'blogid_detail' ||		// マルチブログ詳細
 			$task == 'config'){		// ブログ設定
 			
 			// カテゴリ設定
 			$current = '';
 			$link = $baseUrl . '&task=category';
 			if ($task == 'category' || $task == 'category_detail') $current = 'id="current"';
-			$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>カテゴリ設定</span></a></li>' . M3_NL;
+			$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>カテゴリ</span></a></li>' . M3_NL;
+			
+			// マルチブログ
+			$current = '';
+			$link = $baseUrl . '&task=blogid';
+			if ($task == 'blogid' || $task == 'blogid_detail') $current = 'id="current"';
+			$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span>マルチブログ</span></a></li>' . M3_NL;
 			
 			// その他設定
 			$current = '';
@@ -145,5 +180,27 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 		$outputText .= '<table width="90%"><tr><td>' . $linkList . $menuText . '</td></tr></table>' . M3_NL;
 		$this->tmpl->addVar("_widget", "menu_items", $outputText);
 	}
+	/**
+	 * ブログ定義値をDBから取得
+	 *
+	 * @return bool			true=取得成功、false=取得失敗
+	 */
+	function _loadConfig()
+	{
+		$this->_configArray = array();
+
+		// ブログ定義を読み込み
+		$ret = $this->_db->getAllConfig($rows);
+		if ($ret){
+			// 取得データを連想配列にする
+			$configCount = count($rows);
+			for ($i = 0; $i < $configCount; $i++){
+				$key = $rows[$i]['bg_id'];
+				$value = $rows[$i]['bg_value'];
+				$this->_configArray[$key] = $value;
+			}
+		}
+		return $ret;
+	}
 }
 ?>
