@@ -10,13 +10,26 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainDb.php 3579 2010-09-10 08:54:51Z fishbone $
+ * @version    SVN: $Id: blog_mainDb.php 3620 2010-09-23 09:20:20Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
 
 class blog_mainDb extends BaseDb
 {
+	/**
+	 * ブログ定義値を取得をすべて取得
+	 *
+	 * @param array  $rows			レコード
+	 * @return bool					1行以上取得 = true, 取得なし= false
+	 */
+	function getAllConfig(&$rows)
+	{
+		$queryStr  = 'SELECT * FROM blog_config ';
+		$queryStr .=   'ORDER BY bg_index';
+		$retValue = $this->selectRecords($queryStr, array(), $rows);
+		return $retValue;
+	}
 	/**
 	 * ブログ定義値を取得
 	 *
@@ -209,10 +222,11 @@ class blog_mainDb extends BaseDb
 		$initDt = $this->gEnv->getInitValueOfTimestamp();		// 日時初期化値
 		$params = array();
 		
-		$queryStr = 'SELECT * FROM blog_entry ';
-		$queryStr .=  'WHERE be_language_id = ? ';	$params[] = $langId;
-		$queryStr .=    'AND be_deleted = false ';		// 削除されていない
-		$queryStr .=    'AND be_regist_dt <= ? ';	$params[] = $now;	// 投稿日時が現在日時よりも過去のものを取得
+		//$queryStr = 'SELECT * FROM blog_entry ';
+		$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+		$queryStr .=   'WHERE be_language_id = ? ';	$params[] = $langId;
+		$queryStr .=     'AND be_deleted = false ';		// 削除されていない
+		$queryStr .=     'AND be_regist_dt <= ? ';	$params[] = $now;	// 投稿日時が現在日時よりも過去のものを取得
 
 		// タイトルと記事を検索
 		if (!empty($keyword)){
@@ -282,12 +296,13 @@ class blog_mainDb extends BaseDb
 	 * エントリー項目の新規追加
 	 *
 	 * @param string  $id			エントリーID
-	 * @param string  $langId			言語ID
+	 * @param string  $langId		言語ID
 	 * @param string  $name			コンテンツ名
 	 * @param string  $html			HTML
 	 * @param string  $html2		HTML(続き)
 	 * @param int     $status		エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
 	 * @param array   $category		カテゴリーID
+	 * @param string  $blogId		ブログID
 	 * @param int     $regUserId	投稿者ユーザID
 	 * @param timestamp $regDt		投稿日時
 	 * @param timestamp	$startDt	期間(開始日)
@@ -297,7 +312,7 @@ class blog_mainDb extends BaseDb
 	 * @param bool $receiveComment	コメントを受け付けるかどうか
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function addEntryItem($id, $langId, $name, $html, $html2, $status, $category, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial)
+	function addEntryItem($id, $langId, $name, $html, $html2, $status, $category, $blogId, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -338,11 +353,13 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   '(be_id, ';
 		$queryStr .=   'be_language_id, ';
 		$queryStr .=   'be_history_index, ';
-		$queryStr .=   'be_name, be_html, ';
+		$queryStr .=   'be_name, ';
+		$queryStr .=   'be_html, ';
 		$queryStr .=   'be_html_ext, ';
 		$queryStr .=   'be_status, ';
 		$queryStr .=   'be_show_comment, ';
 		$queryStr .=   'be_receive_comment, ';
+		$queryStr .=   'be_blog_id, ';
 		$queryStr .=   'be_regist_user_id, ';
 		$queryStr .=   'be_regist_dt, ';
 		$queryStr .=   'be_active_start_dt, ';
@@ -350,9 +367,9 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_create_user_id, ';
 		$queryStr .=   'be_create_dt) ';
 		$queryStr .= 'VALUES ';
-		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
 		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
-												intval($showComment), intval($receiveComment), $regUserId, $regDt, $startDt, $endDt, $userId, $now));
+												intval($showComment), intval($receiveComment), $blogId, $regUserId, $regDt, $startDt, $endDt, $userId, $now));
 		
 		// 新規のシリアル番号取得
 		$newSerial = 0;
@@ -382,6 +399,7 @@ class blog_mainDb extends BaseDb
 	 * @param string  $html2		HTML(続き)
 	 * @param int     $status		エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
 	 * @param array   $category		カテゴリーID
+	 * @param string  $blogId		ブログID
 	 * @param int     $regUserId	投稿者ユーザID(0のときは更新しない)
 	 * @param timestamp $regDt		投稿日時(空のときは更新しない)
 	 * @param timestamp	$startDt	期間(開始日)
@@ -391,7 +409,7 @@ class blog_mainDb extends BaseDb
 	 * @param int     $newSerial	新規シリアル番号
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function updateEntryItem($serial, $name, $html, $html2, $status, $category, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial)
+	function updateEntryItem($serial, $name, $html, $html2, $status, $category, $blogId, $regUserId, $regDt, $startDt, $endDt, $showComment, $receiveComment, &$newSerial)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -447,6 +465,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_status, ';
 		$queryStr .=   'be_show_comment, ';
 		$queryStr .=   'be_receive_comment, ';
+		$queryStr .=   'be_blog_id, ';
 		$queryStr .=   'be_regist_user_id, ';
 		$queryStr .=   'be_regist_dt, ';
 		$queryStr .=   'be_active_start_dt, ';
@@ -454,9 +473,9 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_create_user_id, ';
 		$queryStr .=   'be_create_dt) ';
 		$queryStr .= 'VALUES ';
-		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
 		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
-												intval($showComment), intval($receiveComment), $rUserId, $rDt, $startDt, $endDt, $userId, $now));
+												intval($showComment), intval($receiveComment), $blogId, $rUserId, $rDt, $startDt, $endDt, $userId, $now));
 
 		// 新規のシリアル番号取得
 		$newSerial = 0;
@@ -636,7 +655,7 @@ class blog_mainDb extends BaseDb
 	 */
 	function getEntryItem($id, $langId, &$row)
 	{
-		$queryStr  = 'SELECT * FROM blog_entry ';
+		$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
 		$queryStr .=   'WHERE be_deleted = false ';	// 削除されていない
 		$queryStr .=   'AND be_id = ? ';
 		$queryStr .=   'AND be_language_id = ? ';
@@ -655,9 +674,10 @@ class blog_mainDb extends BaseDb
 	 * @param string	$langId				言語
 	 * @param int		$order				取得順(0=昇順,1=降順)
 	 * @param function	$callback			コールバック関数
+	 * @param string	$blogId				ブログID(nullのとき指定なし)
 	 * @return 			なし
 	 */
-	function getEntryItems($limit, $page, $now, $entryId, $startDt, $endDt, $langId, $order, $callback)
+	function getEntryItems($limit, $page, $now, $entryId, $startDt, $endDt, $langId, $order, $callback, $blogId = null)
 	{
 		$offset = $limit * ($page -1);
 		if ($offset < 0) $offset = 0;
@@ -666,12 +686,17 @@ class blog_mainDb extends BaseDb
 		
 		// エントリーIDの指定がない場合は、期間で取得
 		if (empty($entryId)){
-			$queryStr = 'SELECT * FROM blog_entry ';
-			$queryStr .=  'WHERE be_deleted = false ';		// 削除されていない
-			$queryStr .=    'AND be_status = ? ';		$params[] = 2;	// 「公開」(2)データを表示
-			$queryStr .=    'AND be_language_id = ? ';	$params[] = $langId;
-			$queryStr .=    'AND be_regist_dt <= ? ';	$params[] = $now;		// 投稿日時が現在日時よりも過去のものを取得
+			$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=   'WHERE be_deleted = false ';		// 削除されていない
+			$queryStr .=     'AND be_status = ? ';		$params[] = 2;	// 「公開」(2)データを表示
+			$queryStr .=     'AND be_language_id = ? ';	$params[] = $langId;
+			$queryStr .=     'AND be_regist_dt <= ? ';	$params[] = $now;		// 投稿日時が現在日時よりも過去のものを取得
 			
+			// ブログID
+			if (isset($blogId)){
+				$queryStr .=    'AND be_blog_id = ? ';		$params[] = $blogId;
+			}
+		
 			// 検索条件
 			if (!empty($startDt)){
 				$queryStr .=    'AND ? <= be_regist_dt ';
@@ -697,12 +722,18 @@ class blog_mainDb extends BaseDb
 			$queryStr .=  'ORDER BY be_regist_dt ' . $ord . 'LIMIT ' . $limit . ' offset ' . $offset;// 投稿順
 			$this->selectLoop($queryStr, $params, $callback, null);
 		} else {
-			$queryStr = 'SELECT * FROM blog_entry ';
-			$queryStr .=  'WHERE be_deleted = false ';		// 削除されていない
-			$queryStr .=    'AND be_status = ? ';	$params[] = 2;	// 「公開」(2)データを表示
-			$queryStr .=    'AND be_id = ? ';		$params[] = $entryId;
-			$queryStr .=    'AND be_language_id = ? ';	$params[] = $langId;
-			$queryStr .=    'AND be_regist_dt <= ? ';	$params[] = $now;		// 投稿日時が現在日時よりも過去のものを取得
+			//$queryStr = 'SELECT * FROM blog_entry ';
+			$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+			$queryStr .=   'WHERE be_deleted = false ';		// 削除されていない
+			$queryStr .=     'AND be_status = ? ';	$params[] = 2;	// 「公開」(2)データを表示
+			$queryStr .=     'AND be_id = ? ';		$params[] = $entryId;
+			$queryStr .=     'AND be_language_id = ? ';	$params[] = $langId;
+			$queryStr .=     'AND be_regist_dt <= ? ';	$params[] = $now;		// 投稿日時が現在日時よりも過去のものを取得
+			
+			// ブログID
+			if (isset($blogId)){
+				$queryStr .=    'AND be_blog_id = ? ';		$params[] = $blogId;
+			}
 			
 			// 公開期間を指定
 			$queryStr .=    'AND (be_active_start_dt = ? OR (be_active_start_dt != ? AND be_active_start_dt <= ?)) ';
@@ -724,9 +755,10 @@ class blog_mainDb extends BaseDb
 	 * @param timestamp	$startDt			期間(開始日)
 	 * @param timestamp	$endDt				期間(終了日)
 	 * @param string	$langId				言語
+	 * @param string	$blogId				ブログID(nullのとき指定なし)
 	 * @return int							項目数
 	 */
-	function getEntryItemsCount($now, $startDt, $endDt, $langId)
+	function getEntryItemsCount($now, $startDt, $endDt, $langId, $blogId = null)
 	{
 		$initDt = $this->gEnv->getInitValueOfTimestamp();		// 日時初期化値
 		$params = array();
@@ -737,6 +769,11 @@ class blog_mainDb extends BaseDb
 		$queryStr .=    'AND be_language_id = ? ';	$params[] = $langId;
 		$queryStr .=    'AND be_regist_dt <= ? ';	$params[] = $now;		// 投稿日時が現在日時よりも過去のものを取得
 		
+		// ブログID
+		if (isset($blogId)){
+			$queryStr .=    'AND be_blog_id = ? ';		$params[] = $blogId;
+		}
+		
 		// 検索条件
 		if (!empty($startDt)){
 			$queryStr .=    'AND ? <= be_regist_dt ';
@@ -805,8 +842,9 @@ class blog_mainDb extends BaseDb
 		$serialStr = implode(',', $serialArray);
 		if (empty($serialStr)) $serialStr = '0';	// 0レコードのときはダミー値を設定
 	
-		$queryStr = 'SELECT * FROM blog_entry ';
-		$queryStr .=  'WHERE be_serial in (' . $serialStr . ') ';
+		//$queryStr = 'SELECT * FROM blog_entry ';
+		$queryStr  = 'SELECT * FROM blog_entry LEFT JOIN blog_id ON be_blog_id = bl_id AND bl_deleted = false ';
+		$queryStr .=   'WHERE be_serial in (' . $serialStr . ') ';
 		$ord = '';
 		if (!empty($order)) $ord = 'DESC ';
 		$queryStr .=  'ORDER BY be_regist_dt ' . $ord . 'LIMIT ' . $limit . ' offset ' . $offset;// 投稿順
@@ -884,5 +922,264 @@ class blog_mainDb extends BaseDb
 		$retValue = $this->selectRecords($queryStr, array($langId), $rows);
 		return $retValue;
 	}
+	/**
+	 * すべてのブログIDを取得
+	 *
+	 * @param array   $rows			取得レコード
+	 * @return bool					取得 = true, 取得なし= false
+	 */
+	function getAllBlogId(&$rows)
+	{
+		$queryStr  = 'SELECT * FROM blog_id ';
+		$queryStr .=  'WHERE bl_deleted = false ';		// 削除されていない
+		$queryStr .=  'ORDER BY bl_index, bl_id';
+		$retValue = $this->selectRecords($queryStr, array(), $rows);
+		return $retValue;
+	}
+	/**
+	 * ブログ一覧を取得(管理用)
+	 *
+	 * @param function	$callback			コールバック関数
+	 * @return 			なし
+	 */
+	function getAllBlogInfo($callback)
+	{
+		$queryStr = 'SELECT * FROM blog_id LEFT JOIN _login_user ON bl_owner_id = lu_id AND lu_deleted = false ';
+		$queryStr .=  'WHERE bl_deleted = false ';		// 削除されていない
+		$queryStr .=  'ORDER BY bl_index, bl_id';
+		$this->selectLoop($queryStr, array(), $callback);
+	}
+	/**
+	 * ブログ情報を識別IDで取得(管理用)
+	 *
+	 * @param string	$id					識別ID
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getBlogInfoById($id, &$row)
+	{
+		$queryStr = 'SELECT * FROM blog_id ';
+		$queryStr .=  'WHERE bl_deleted = false ';
+		$queryStr .=  'AND bl_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($id), $row);
+		return $ret;
+	}
+	/**
+	 * ブログ情報をシリアル番号で取得
+	 *
+	 * @param string	$serial				シリアル番号
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getBlogInfoBySerial($serial, &$row)
+	{
+		$queryStr  = 'SELECT * FROM blog_id LEFT JOIN _login_user ON bl_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=   'WHERE bl_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		return $ret;
+	}
+	/**
+	 * 公開可能なブログ情報かどうか
+	 *
+	 * @param string	$id			識別ID
+	 * @return bool					true=存在する、false=存在しない
+	 */
+	function isActiveBlogInfo($id)
+	{
+		$queryStr = 'SELECT * FROM blog_id ';
+		$queryStr .=  'WHERE bl_deleted = false ';
+		$queryStr .=  'AND bl_visible = true ';
+		$queryStr .=  'AND bl_id = ? ';
+		return $this->isRecordExists($queryStr, array($id));
+	}
+	/**
+	 * ブログ情報を更新
+	 *
+	 * @param string $serial		シリアル番号(0のときは新規登録)
+	 * @param string $id			ブログID
+	 * @param string $name			名前
+	 * @param int    $index			表示順
+	 * @param string $templateId	テンプレートID
+	 * @param bool $visible			表示制御
+	 * @param string  $metaTitle	METAタグ、タイトル
+	 * @param string  $metaDesc		METAタグ、ページ要約
+	 * @param string  $metaKeyword	METAタグ、検索用キーワード
+	 * @param int    $ownerId		所有者ID
+	 * @param int $newSerial	新規シリアル番号
+	 * @return					true = 正常、false=異常
+	 */
+	function updateBlogInfo($serial, $id, $name, $index, $templateId, $visible, $metaTitle, $metaDesc, $metaKeyword, $ownerId, &$newSerial)
+	{
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
+		$contentUpdateDt = $this->gEnv->getInitValueOfTimestamp();
+		
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 前レコードの削除状態チェック
+		$historyIndex = 0;
+		$desc = '';
+		if (empty($serial)){		// 新規登録のとき
+			$queryStr = 'SELECT * FROM blog_id ';
+			$queryStr .=  'WHERE bl_id = ? ';
+			$queryStr .=  'ORDER BY bl_history_index DESC ';
+			$ret = $this->selectRecord($queryStr, array($id), $row);
+			if ($ret){
+				if (!$row['bl_deleted']){		// レコード存在していれば終了
+					$this->endTransaction();
+					return false;
+				}
+				$historyIndex = $row['bl_history_index'] + 1;
+			}
+		} else {		// 更新のとき
+			// 指定のシリアルNoのレコードが削除状態でないかチェック
+			$queryStr  = 'SELECT * FROM blog_id ';
+			$queryStr .=   'WHERE bl_serial = ? ';
+			$ret = $this->selectRecord($queryStr, array($serial), $row);
+			if ($ret){		// 既に登録レコードがあるとき
+				if ($row['bl_deleted']){		// レコードが削除されていれば終了
+					$this->endTransaction();
+					return false;
+				}
+				$historyIndex = $row['bl_history_index'] + 1;
+				
+				// 識別IDとコンテンツ更新日時の変更は不可
+				$id = $row['bl_id'];
+				$contentUpdateDt = $row['bl_content_update_dt'];
+			} else {		// 存在しない場合は終了
+				$this->endTransaction();
+				return false;
+			}
+			
+			// 古いレコードを削除
+			$queryStr  = 'UPDATE blog_id ';
+			$queryStr .=   'SET bl_deleted = true, ';	// 削除
+			$queryStr .=     'bl_update_user_id = ?, ';
+			$queryStr .=     'bl_update_dt = ? ';
+			$queryStr .=   'WHERE bl_serial = ?';
+			$ret = $this->execStatement($queryStr, array($userId, $now, $serial));
+			if (!$ret){
+				$this->endTransaction();
+				return false;
+			}
+		}
+		
+		// データを追加
+		$queryStr = 'INSERT INTO blog_id ';
+		$queryStr .=  '(bl_id, bl_history_index, bl_name, bl_index, bl_template_id, bl_visible, bl_meta_title, bl_meta_description, bl_meta_keywords, bl_owner_id, bl_content_update_dt, bl_create_user_id, bl_create_dt) ';
+		$queryStr .=  'VALUES ';
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($id, $historyIndex, $name, $index, $templateId, intval($visible), $metaTitle, $metaDesc, $metaKeyword, intval($ownerId), $contentUpdateDt, $userId, $now));
+		
+		// 新規のシリアル番号取得
+		$queryStr = 'SELECT MAX(bl_serial) AS ns FROM blog_id ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $newSerial = $row['ns'];
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
+	/**
+	 * ブログ情報の削除
+	 *
+	 * @param array $serial			シリアルNo
+	 * @return						true=成功、false=失敗
+	 */
+	function delBlogInfo($serial)
+	{
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$user = $this->gEnv->getCurrentUserId();	// 現在のユーザ
+		
+		if (!is_array($serial) || count($serial) <= 0) return true;
+		
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		for ($i = 0; $i < count($serial); $i++){
+			$queryStr  = 'SELECT * FROM blog_id ';
+			$queryStr .=   'WHERE bl_deleted = false ';		// 未削除
+			$queryStr .=     'AND bl_serial = ? ';
+			$ret = $this->isRecordExists($queryStr, array($serial[$i]));
+			// 存在しない場合は、既に削除されたとして終了
+			if (!$ret){
+				$this->endTransaction();
+				return false;
+			}
+		}
+		
+		// レコードを削除
+		$queryStr  = 'UPDATE blog_id ';
+		$queryStr .=   'SET bl_deleted = true, ';	// 削除
+		$queryStr .=     'bl_update_user_id = ?, ';
+		$queryStr .=     'bl_update_dt = ? ';
+		$queryStr .=   'WHERE bl_serial in (' . implode($serial, ',') . ') ';
+		$this->execStatement($queryStr, array($user, $now));
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
+	/**
+	 * 最大表示順を取得
+	 *
+	 * @return int					最大表示順
+	 */
+	function getBlogInfoMaxIndex()
+	{
+		$queryStr = 'SELECT max(bl_index) as mi FROM blog_id ';
+		$queryStr .=  'WHERE bl_deleted = false ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret){
+			$index = $row['mi'];
+		} else {
+			$index = 0;
+		}
+		return $index;
+	}
+	/**
+	 * テンプレートリスト取得
+	 *
+	 * @param int      $type		テンプレートのタイプ(0=PC用、1=携帯用、2=スマートフォン)
+	 * @param function $callback	コールバック関数
+	 * @return						なし
+	 */
+	function getAllTemplateList($type, $callback)
+	{
+		// tm_device_typeは後で追加したため、tm_mobileを残しておく
+		$queryStr = 'SELECT * FROM _templates ';
+		$queryStr .=  'WHERE tm_deleted = false ';// 削除されていない
+		$params = array();
+		switch ($type){
+			case 0:		// PC用テンプレート
+			case 2:		// スマートフォン用テンプレート
+			default:
+				$queryStr .=    'AND tm_mobile = false ';		// 携帯用以外
+				$queryStr .=    'AND tm_device_type = ? '; $params[] = $type;
+				break;
+			case 1:		// 携帯用のとき
+				$queryStr .=    'AND tm_mobile = true ';		// 携帯用
+				break;
+		}
+		$queryStr .=  'ORDER BY tm_id';
+		$this->selectLoop($queryStr, $params, $callback);
+	}
+	/**
+	 * ユーザリスト取得
+	 *
+	 * @param int      $minLevel	最小のユーザレベル
+	 * @param function $callback	コールバック関数
+	 * @return						なし
+	 */
+	function getUserList($minLevel, $callback)
+	{
+		$queryStr  = 'SELECT * FROM _login_user ';
+		$queryStr .=   'WHERE lu_deleted = false ';// 削除されていない
+		$queryStr .=     'AND lu_user_type >= ? ';		// ユーザレベル
+		$queryStr .=   'ORDER BY lu_user_type, lu_account';
+		$this->selectLoop($queryStr, array($minLevel), $callback);
+	}
 }
 ?>
